@@ -290,7 +290,38 @@ def main():
                 print(bcolors.OKBLUE+'START DVC REPRO ' + f + '   ' + get_time()+bcolors.ENDC)
                 command = 'sh '+os.path.realpath(__file__)[:-7]+'start_dvc_repro.sh ' + f + ' ' + f.replace('/','_') + ' ' + path_to_save_output
                 #command = 'sh '+os.path.realpath(__file__)[:-7]+'start_dvc_repro.sh'
-                print(subprocess.check_output(command.split(' ')).decode())
+                message = subprocess.check_output(command.split(' ')).decode()
+
+                if message.find('ERROR: failed to reproduce') >= 0:
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print(message)
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    print()
+                    raise RuntimeError(message)
+                else:
+                    print(message)
             else:
                 print('WARNING: A file that should be execute ('+f+') does not ends with .dvc. The job is skipped!')
         subprocess.call(['git','add','stdout_stderr/*'])
